==> mk-element-ui2-2.4.9-RC3.tgz: package/src/index.js <==

import Pagination from '../packages/pagination/index.js';
import Dialog from '../packages/dialog/index.js';
import Autocomplete from '../packages/autocomplete/index.js';
import Dropdown from '../packages/dropdown/index.js';
import DropdownMenu from '../packages/dropdown-menu/index.js';
import DropdownItem from '../packages/dropdown-item/index.js';
import Menu from '../packages/menu/index.js';
import Submenu from '../packages/submenu/index.js';
import MenuItem from '../packages/menu-item/index.js';
import MenuItemGroup from '../packages/menu-item-group/index.js';
import Input from '../packages/input/index.js';
import InputNumber from '../packages/input-number/index.js';
import Radio from '../packages/radio/index.js';
import RadioGroup from '../packages/radio-group/index.js';
import RadioButton from '../packages/radio-button/index.js';
import Checkbox from '../packages/checkbox/index.js';
import CheckboxButton from '../packages/checkbox-button/index.js';
import CheckboxGroup from '../packages/checkbox-group/index.js';
import Switch from '../packages/switch/index.js';
import Select from '../packages/select/index.js';
import Option from '../packages/option/index.js';
import OptionGroup from '../packages/option-group/index.js';
import Button from '../packages/button/index.js';
import ButtonGroup from '../packages/button-group/index.js';
import Table from '../packages/table/index.js';
import TableColumn from '../packages/table-column/index.js';
import DatePicker from '../packages/date-picker/index.js';
import TimeSelect from '../packages/time-select/index.js';
import TimePicker from '../packages/time-picker/index.js';
import Popover from '../packages/popover/index.js';
import Tooltip from '../packages/tooltip/index.js';
import MessageBox from '../packages/message-box/index.js';
import Breadcrumb from '../packages/breadcrumb/index.js';
import BreadcrumbItem from '../packages/breadcrumb-item/index.js';
import Form from '../packages/form/index.js';
import FormItem from '../packages/form-item/index.js';
import Tabs from '../packages/tabs/index.js';
import TabPane from '../packages/tab-pane/index.js';
import Tag from '../packages/tag/index.js';
import Tree from '../packages/tree/index.js';
import Alert from '../packages/alert/index.js';
import Notification from '../packages/notification/index.js';
import Slider from '../packages/slider/index.js';
import Loading from '../packages/loading/index.js';
import Icon from '../packages/icon/index.js';
import Row from '../packages/row/index.js';
import Col from '../packages/col/index.js';
import Upload from '../packages/upload/index.js';
import Progress from '../packages/progress/index.js';
import Spinner from '../packages/spinner/index.js';
import Message from '../packages/message/index.js';
import Badge from '../packages/badge/index.js';
import Card from '../packages/card/index.js';
import Rate from '../packages/rate/index.js';
import Steps from '../packages/steps/index.js';
import Step from '../packages/step/index.js';
import Carousel from '../packages/carousel/index.js';
import Scrollbar from '../packages/scrollbar/index.js';
import CarouselItem from '../packages/carousel-item/index.js';
import Collapse from '../packages/collapse/index.js';
import CollapseItem from '../packages/collapse-item/index.js';
import Cascader from '../packages/cascader/index.js';
import ColorPicker from '../packages/color-picker/index.js';
import Transfer from '../packages/transfer/index.js';
import Container from '../packages/container/index.js';
import Header from '../packages/header/index.js';
import Aside from '../packages/aside/index.js';
import Main from '../packages/main/index.js';
import Footer from '../packages/footer/index.js';
import MkBottomBox from '../packages/mk-bottom-box/index.js';
import MkButton from '../packages/mk-button/index.js';
import MkCascader from '../packages/mk-cascader/index.js';
import MkColBox from '../packages/mk-col-box/index.js';
import MkImgView from '../packages/mk-img-view/index.js';
import MkSearchBox from '../packages/mk-search-box/index.js';
import MkSearchTableBox from '../packages/mk-search-table-box/index.js';
import MkSearchLabel from '../packages/mk-search-label/index.js';
import MkTab from '../packages/mk-tab/index.js';
import MkTabItem from '../packages/mk-tab-item/index.js';
import MkTable from '../packages/mk-table/index.js';
import MkTimerBtn from '../packages/mk-timer-btn/index.js';
import MkTree from '../packages/mk-tree/index.js';
import MkSearchButtons from '../packages/mk-search-buttons/index.js';
import MkConfigSelect from '../packages/mk-config-select/index.js';
import MkHr from '../packages/mk-hr/index.js';
import MkUpload from '../packages/mk-upload/index.js';
import MkConfigRadio from '../packages/mk-config-radio/index.js';
import MkCard from '../packages/mk-card/index.js';
import MkFormItem from '../packages/mk-form-item/index.js';
import MkButtonBadge from '../packages/mk-button-badge/index.js';
import MkInline from '../packages/mk-inline/index.js';
import MkDialog from '../packages/mk-dialog/index.js';
import MkAxios from './prototypes/mk-axios.js';
import MkCache from './prototypes/mk-cache.js';
import MkDom from './prototypes/mk-dom.js';
import MkLang from './prototypes/mk-lang.js';
import MkBus from './prototypes/mk-bus.js';
import MkMathPrototypes from './prototypes/mk-math-prototypes.js';
import MkDataPrototypes from './prototypes/mk-data-prototypes.js';
import MkMath from './filters/mk-math.js';
import MkData from './filters/mk-data.js';
import MkAutoHeight from './directives/mk-auto-height.js';
import MkAutoMaxHeight from './directives/mk-auto-max-height.js';
import MkCursor from './directives/mk-cursor.js';
import MkFocus from './directives/mk-focus.js';
import MkStore from './store/mk-store.js';
import MkRole from './interceptors/mk-role.js';
import MkVersion from './helps/mk-version.js';
import MkBase from './mixins/mk-base.js';
import locale from 'mk-element-ui2/src/locale';
import CollapseTransition from 'mk-element-ui2/src/transitions/collapse-transition';

const components = [
  Pagination,
  Dialog,
  Autocomplete,
  Dropdown,
  DropdownMenu,
  DropdownItem,
  Menu,
  Submenu,
  MenuItem,
  MenuItemGroup,
  Input,
  InputNumber,
  Radio,
  RadioGroup,
  RadioButton,
  Checkbox,
  CheckboxButton,
  CheckboxGroup,
  Switch,
  Select,
  Option,
  OptionGroup,
  Button,
  ButtonGroup,
  Table,
  TableColumn,
  DatePicker,
  TimeSelect,
  TimePicker,
  Popover,
  Tooltip,
  Breadcrumb,
  BreadcrumbItem,
  Form,
  FormItem,
  Tabs,
  TabPane,
  Tag,
  Tree,
  Alert,
  Slider,
  Icon,
  Row,
  Col,
  Upload,
  Progress,
  Spinner,
  Badge,
  Card,
  Rate,
  Steps,
  Step,
  Carousel,
  Scrollbar,
  CarouselItem,
  Collapse,
  CollapseItem,
  Cascader,
  ColorPicker,
  Transfer,
  Container,
  Header,
  Aside,
  Main,
  Footer,
  MkBottomBox,
  MkButton,
  MkCascader,
  MkColBox,
  MkImgView,
  MkSearchBox,
  MkSearchTableBox,
  MkSearchLabel,
  MkTab,
  MkTabItem,
  MkTable,
  MkTimerBtn,
  MkTree,
  MkSearchButtons,
  MkConfigSelect,
  MkHr,
  MkUpload,
  MkConfigRadio,
  MkCard,
  MkFormItem,
  MkButtonBadge,
  MkInline,
  MkDialog,
  CollapseTransition
];

const install = function(Vue, opts = {}) {
  locale.use(opts.locale);
  locale.i18n(opts.i18n);

  components.map(component => {
    Vue.component(component.name, component);
  });

  Vue.use(Loading.directive);
  Vue.directive('popover', Popover.directive);
  Vue.use(MkAxios, opts);
  Vue.use(MkCache, opts);
  Vue.use(MkDom, opts);
  Vue.use(MkLang, opts);
  Vue.use(MkBus, opts);
  Vue.use(MkMathPrototypes, opts);
  Vue.use(MkDataPrototypes, opts);
  Vue.use(MkMath, opts);
  Vue.use(MkData, opts);
  Vue.use(MkAutoHeight, opts);
  Vue.use(MkAutoMaxHeight, opts);
  Vue.use(MkCursor, opts);
  Vue.use(MkFocus, opts);
  Vue.use(MkRole, opts);
  Vue.use(MkVersion, opts);

  Vue.prototype.$ELEMENT = {
    size: opts.size || '',
    zIndex: opts.zIndex || 2000
  };

  Vue.prototype.$loading = Loading.service;
  Vue.prototype.$msgbox = MessageBox;
  Vue.prototype.$alert = MessageBox.alert;
  Vue.prototype.$confirm = MessageBox.confirm;
  Vue.prototype.$prompt = MessageBox.prompt;
  Vue.prototype.$notify = Notification;
  Vue.prototype.$message = Message;
};

/* istanbul ignore if */
if (typeof window !== 'undefined' && window.Vue) {
  install(window.Vue);
}

module.exports = {
  version: '2.4.9-RC2',
  locale: locale.use,
  i18n: locale.i18n,
  install,
  CollapseTransition,
  Loading,
  Pagination,
  Dialog,
  Autocomplete,
  Dropdown,
  DropdownMenu,
  DropdownItem,
  Menu,
  Submenu,
  MenuItem,
  MenuItemGroup,
  Input,
  InputNumber,
  Radio,
  RadioGroup,
  RadioButton,
  Checkbox,
  CheckboxButton,
  CheckboxGroup,
  Switch,
  Select,
  Option,
  OptionGroup,
  Button,
  ButtonGroup,
  Table,
  TableColumn,
  DatePicker,
  TimeSelect,
  TimePicker,
  Popover,
  Tooltip,
  MessageBox,
  Breadcrumb,
  BreadcrumbItem,
  Form,
  FormItem,
  Tabs,
  TabPane,
  Tag,
  Tree,
  Alert,
  Notification,
  Slider,
  Icon,
  Row,
  Col,
  Upload,
  Progress,
  Spinner,
  Message,
  Badge,
  Card,
  Rate,
  Steps,
  Step,
  Carousel,
  Scrollbar,
  CarouselItem,
  Collapse,
  CollapseItem,
  Cascader,
  ColorPicker,
  Transfer,
  Container,
  Header,
  Aside,
  Main,
  Footer,
  MkBottomBox,
  MkButton,
  MkCascader,
  MkColBox,
  MkImgView,
  MkSearchBox,
  MkSearchTableBox,
  MkSearchLabel,
  MkTab,
  MkTabItem,
  MkTable,
  MkTimerBtn,
  MkTree,
  MkSearchButtons,
  MkConfigSelect,
  MkHr,
  MkUpload,
  MkConfigRadio,
  MkCard,
  MkFormItem,
  MkButtonBadge,
  MkInline,
  MkDialog,
  MkStore,
  MkBase
};

module.exports.default = module.exports;

==> mk-element-ui-2.4.9-RC3.tgz: package/src/index.js <==

import Pagination from '../packages/pagination/index.js';
import Dialog from '../packages/dialog/index.js';
import Autocomplete from '../packages/autocomplete/index.js';
import Dropdown from '../packages/dropdown/index.js';
import DropdownMenu from '../packages/dropdown-menu/index.js';
import DropdownItem from '../packages/dropdown-item/index.js';
import Menu from '../packages/menu/index.js';
import Submenu from '../packages/submenu/index.js';
import MenuItem from '../packages/menu-item/index.js';
import MenuItemGroup from '../packages/menu-item-group/index.js';
import Input from '../packages/input/index.js';
import InputNumber from '../packages/input-number/index.js';
import Radio from '../packages/radio/index.js';
import RadioGroup from '../packages/radio-group/index.js';
import RadioButton from '../packages/radio-button/index.js';
import Checkbox from '../packages/checkbox/index.js';
import CheckboxButton from '../packages/checkbox-button/index.js';
import CheckboxGroup from '../packages/checkbox-group/index.js';
import Switch from '../packages/switch/index.js';
import Select from '../packages/select/index.js';
import Option from '../packages/option/index.js';
import OptionGroup from '../packages/option-group/index.js';
import Button from '../packages/button/index.js';
import ButtonGroup from '../packages/button-group/index.js';
import Table from '../packages/table/index.js';
import TableColumn from '../packages/table-column/index.js';
import DatePicker from '../packages/date-picker/index.js';
import TimeSelect from '../packages/time-select/index.js';
import TimePicker from '../packages/time-picker/index.js';
import Popover from '../packages/popover/index.js';
import Tooltip from '../packages/tooltip/index.js';
import MessageBox from '../packages/message-box/index.js';
import Breadcrumb from '../packages/breadcrumb/index.js';
import BreadcrumbItem from '../packages/breadcrumb-item/index.js';
import Form from '../packages/form/index.js';
import FormItem from '../packages/form-item/index.js';
import Tabs from '../packages/tabs/index.js';
import TabPane from '../packages/tab-pane/index.js';
import Tag from '../packages/tag/index.js';
import Tree from '../packages/tree/index.js';
import Alert from '../packages/alert/index.js';
import Notification from '../packages/notification/index.js';
import Slider from '../packages/slider/index.js';
import Loading from '../packages/loading/index.js';
import Icon from '../packages/icon/index.js';
import Row from '../packages/row/index.js';
import Col from '../packages/col/index.js';
import Upload from '../packages/upload/index.js';
import Progress from '../packages/progress/index.js';
import Spinner from '../packages/spinner/index.js';
import Message from '../packages/message/index.js';
import Badge from '../packages/badge/index.js';
import Card from '../packages/card/index.js';
import Rate from '../packages/rate/index.js';
import Steps from '../packages/steps/index.js';
import Step from '../packages/step/index.js';
import Carousel from '../packages/carousel/index.js';
import Scrollbar from '../packages/scrollbar/index.js';
import CarouselItem from '../packages/carousel-item/index.js';
import Collapse from '../packages/collapse/index.js';
import CollapseItem from '../packages/collapse-item/index.js';
import Cascader from '../packages/cascader/index.js';
import ColorPicker from '../packages/color-picker/index.js';
import Transfer from '../packages/transfer/index.js';
import Container from '../packages/container/index.js';
import Header from '../packages/header/index.js';
import Aside from '../packages/aside/index.js';
import Main from '../packages/main/index.js';
import Footer from '../packages/footer/index.js';
import MkBottomBox from '../packages/mk-bottom-box/index.js';
import MkButton from '../packages/mk-button/index.js';
import MkCascader from '../packages/mk-cascader/index.js';
import MkColBox from '../packages/mk-col-box/index.js';
import MkImgView from '../packages/mk-img-view/index.js';
import MkSearchBox from '../packages/mk-search-box/index.js';
import MkSearchTableBox from '../packages/mk-search-table-box/index.js';
import MkSearchLabel from '../packages/mk-search-label/index.js';
import MkTab from '../packages/mk-tab/index.js';
import MkTabItem from '../packages/mk-tab-item/index.js';
import MkTable from '../packages/mk-table/index.js';
import MkTimerBtn from '../packages/mk-timer-btn/index.js';
import MkTree from '../packages/mk-tree/index.js';
import MkSearchButtons from '../packages/mk-search-buttons/index.js';
import MkConfigSelect from '../packages/mk-config-select/index.js';
import MkHr from '../packages/mk-hr/index.js';
import MkUpload from '../packages/mk-upload/index.js';
import MkConfigRadio from '../packages/mk-config-radio/index.js';
import MkCard from '../packages/mk-card/index.js';
import MkFormItem from '../packages/mk-form-item/index.js';
import MkButtonBadge from '../packages/mk-button-badge/index.js';
import MkInline from '../packages/mk-inline/index.js';
import MkDialog from '../packages/mk-dialog/index.js';
import MkAxios from './prototypes/mk-axios.js';
import MkCache from './prototypes/mk-cache.js';
import MkDom from './prototypes/mk-dom.js';
import MkLang from './prototypes/mk-lang.js';
import MkBus from './prototypes/mk-bus.js';
import MkMathPrototypes from './prototypes/mk-math-prototypes.js';
import MkDataPrototypes from './prototypes/mk-data-prototypes.js';
import MkMath from './filters/mk-math.js';
import MkData from './filters/mk-data.js';
import MkAutoHeight from './directives/mk-auto-height.js';
import MkAutoMaxHeight from './directives/mk-auto-max-height.js';
import MkCursor from './directives/mk-cursor.js';
import MkFocus from './directives/mk-focus.js';
import MkStore from './store/mk-store.js';
import MkRole from './interceptors/mk-role.js';
import MkVersion from './helps/mk-version.js';
import MkBase from './mixins/mk-base.js';
import locale from 'element-ui/src/locale';
import CollapseTransition from 'element-ui/src/transitions/collapse-transition';

const components = [
  Pagination,
  Dialog,
  Autocomplete,
  Dropdown,
  DropdownMenu,
  DropdownItem,
  Menu,
  Submenu,
  MenuItem,
  MenuItemGroup,
  Input,
  InputNumber,
  Radio,
  RadioGroup,
  RadioButton,
  Checkbox,
  CheckboxButton,
  CheckboxGroup,
  Switch,
  Select,
  Option,
  OptionGroup,
  Button,
  ButtonGroup,
  Table,
  TableColumn,
  DatePicker,
  TimeSelect,
  TimePicker,
  Popover,
  Tooltip,
  Breadcrumb,
  BreadcrumbItem,
  Form,
  FormItem,
  Tabs,
  TabPane,
  Tag,
  Tree,
  Alert,
  Slider,
  Icon,
  Row,
  Col,
  Upload,
  Progress,
  Spinner,
  Badge,
  Card,
  Rate,
  Steps,
  Step,
  Carousel,
  Scrollbar,
  CarouselItem,
  Collapse,
  CollapseItem,
  Cascader,
  ColorPicker,
  Transfer,
  Container,
  Header,
  Aside,
  Main,
  Footer,
  MkBottomBox,
  MkButton,
  MkCascader,
  MkColBox,
  MkImgView,
  MkSearchBox,
  MkSearchTableBox,
  MkSearchLabel,
  MkTab,
  MkTabItem,
  MkTable,
  MkTimerBtn,
  MkTree,
  MkSearchButtons,
  MkConfigSelect,
  MkHr,
  MkUpload,
  MkConfigRadio,
  MkCard,
  MkFormItem,
  MkButtonBadge,
  MkInline,
  MkDialog,
  CollapseTransition
];

const install = function(Vue, opts = {}) {
  locale.use(opts.locale);
  locale.i18n(opts.i18n);

  components.map(component => {
    Vue.component(component.name, component);
  });

  Vue.use(Loading.directive);
  Vue.directive('popover', Popover.directive);
  Vue.use(MkAxios, opts);
  Vue.use(MkCache, opts);
  Vue.use(MkDom, opts);
  Vue.use(MkLang, opts);
  Vue.use(MkBus, opts);
  Vue.use(MkMathPrototypes, opts);
  Vue.use(MkDataPrototypes, opts);
  Vue.use(MkMath, opts);
  Vue.use(MkData, opts);
  Vue.use(MkAutoHeight, opts);
  Vue.use(MkAutoMaxHeight, opts);
  Vue.use(MkCursor, opts);
  Vue.use(MkFocus, opts);
  Vue.use(MkRole, opts);
  Vue.use(MkVersion, opts);

  Vue.prototype.$ELEMENT = {
    size: opts.size || '',
    zIndex: opts.zIndex || 2000
  };

  Vue.prototype.$loading = Loading.service;
  Vue.prototype.$msgbox = MessageBox;
  Vue.prototype.$alert = MessageBox.alert;
  Vue.prototype.$confirm = MessageBox.confirm;
  Vue.prototype.$prompt = MessageBox.prompt;
  Vue.prototype.$notify = Notification;
  Vue.prototype.$message = Message;
};

/* istanbul ignore if */
if (typeof window !== 'undefined' && window.Vue) {
  install(window.Vue);
}

module.exports = {
  version: '2.4.9-RC3',
  locale: locale.use,
  i18n: locale.i18n,
  install,
  CollapseTransition,
  Loading,
  Pagination,
  Dialog,
  Autocomplete,
  Dropdown,
  DropdownMenu,
  DropdownItem,
  Menu,
  Submenu,
  MenuItem,
  MenuItemGroup,
  Input,
  InputNumber,
  Radio,
  RadioGroup,
  RadioButton,
  Checkbox,
  CheckboxButton,
  CheckboxGroup,
  Switch,
  Select,
  Option,
  OptionGroup,
  Button,
  ButtonGroup,
  Table,
  TableColumn,
  DatePicker,
  TimeSelect,
  TimePicker,
  Popover,
  Tooltip,
  MessageBox,
  Breadcrumb,
  BreadcrumbItem,
  Form,
  FormItem,
  Tabs,
  TabPane,
  Tag,
  Tree,
  Alert,
  Notification,
  Slider,
  Icon,
  Row,
  Col,
  Upload,
  Progress,
  Spinner,
  Message,
  Badge,
  Card,
  Rate,
  Steps,
  Step,
  Carousel,
  Scrollbar,
  CarouselItem,
  Collapse,
  CollapseItem,
  Cascader,
  ColorPicker,
  Transfer,
  Container,
  Header,
  Aside,
  Main,
  Footer,
  MkBottomBox,
  MkButton,
  MkCascader,
  MkColBox,
  MkImgView,
  MkSearchBox,
  MkSearchTableBox,
  MkSearchLabel,
  MkTab,
  MkTabItem,
  MkTable,
  MkTimerBtn,
  MkTree,
  MkSearchButtons,
  MkConfigSelect,
  MkHr,
  MkUpload,
  MkConfigRadio,
  MkCard,
  MkFormItem,
  MkButtonBadge,
  MkInline,
  MkDialog,
  MkStore,
  MkBase
};

module.exports.default = module.exports;
